==> feqhiat_01_08_2017.zip: feqhiat/www/js/controllers.js <==
angular.module('starter.controllers', [])

    .controller('MainCtrl', function (constants, $scope, $ionicLoading, $rootScope,
                                      feqhiatService, $state, utilService, $localStorage) {
        // reset all rootScope variables
        $rootScope.itemID = '';
        $rootScope.bookID = '';
        $rootScope.chapterID = '';
        $rootScope.problemID = '';

        $ionicLoading.show({
            template: 'الرجاء الانتظار'
        });

        var successAllData = function () {
            // save the data to local storage and use it
            $localStorage['allData'] = $scope.allData;
            $scope.allItems =  $localStorage['allData'].items;//$scope.allData.items;
            $ionicLoading.hide();
        };

        var successAllParam = function () {
            $ionicLoading.hide();
            // if version is different force to update
            //alert($localStorage['al_params']);
            if(constants.app_version != utilService.getParamByName("app_version", $scope.al_params).value)
            {
                /// show the update page
                console.log("update");
            }
            // if params not saved before
            else if($localStorage['al_params'] ==  undefined)
            {
                // save it to local storage
                console.log("update DB");
                //console.log(utilService.getParamByName("db_version", $localStorage['al_params']));
                $localStorage['al_params'] = $scope.al_params;
                feqhiatService.getAllData($scope, successAllData);
            }
            else if(utilService.getParamByName("db_version", $localStorage['al_params']).value != utilService.getParamByName("db_version", $scope.al_params).value)
            {
                console.log("update DB 2");
                console.log(utilService.getParamByName("db_version", $localStorage['al_params']));
                $localStorage['al_params'] = $scope.al_params;
                feqhiatService.getAllData($scope, successAllData);
            }
            // check if db version is the same in both server and local
            else //if($window.localStorage['al_params'].db_version == $scope.al_params.db_version)
            {
                $scope.allItems =  $localStorage['allData'].items;//$scope.allData.items;
                $ionicLoading.hide();
            }
            // if not the same, get all data
            //else
            //{
            //    feqhiatService.getAllData($scope, successAllData);
            //}

            // else use the local one
        };

        feqhiatService.getAllParam($scope, successAllParam);

        $scope.navigateToView = function (itemID)
        {
            $rootScope.itemID = itemID;
            $state.go('tab.books');
        };
    })

    .controller('BookCtrl',
        function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope) {
            //$rootScope.itemID = '';
            $rootScope.bookID = '';
            $rootScope.chapterID = '';
            $rootScope.problemID = '';
            $scope.allBooks =  $localStorage.allData.books;

            $scope.navigateToView = function (bookID)
            {
                $rootScope.bookID = bookID;
                $state.go('tab.chapters');
            };
        }

    )

    .controller('ChapterCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope) {
        /*$rootScope.itemID = '';
        $rootScope.bookID = '';*/
        $rootScope.chapterID = '';
        $rootScope.problemID = '';
        $scope.chapters =  utilService.getBookChapters($rootScope.bookID, $localStorage.allData.chapters);

        $scope.navigateToView = function (chapterID)
        {
            $rootScope.chapterID = chapterID;
            $state.go('tab.problem_list');
        };
    }

)

    .controller('ProblemListCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {

        $rootScope.problemID = '';
        var successProblemList = function () {
            $scope.problem_list =  $scope.allData.data;//$scope.allData.items;
            $ionicLoading.hide();
        };

        feqhiatService.getProblemList($rootScope, $scope, successProblemList);
        $scope.navigateToView = function (problemID)
        {
            $rootScope.problemID = problemID;
            $state.go('tab.singleProblem');
        };
    }

)

    .controller('ProblemCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {
        var successProblemSolutions = function () {
            $scope.solutions =  $scope.allData.data;//$scope.allData.items;
            $ionicLoading.hide();
        };

        feqhiatService.getProblemSolutions($rootScope, $scope, successProblemSolutions);

    }

)

  .controller('SendCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {
        $scope.faqih_list = $localStorage['allData'].faqih;
        $scope.books = $localStorage['allData'].books;
        $scope.getChapters = function(bookID) {
            //console.log(bookID);
            $scope.chapters = utilService.getBookChapters(bookID, $localStorage['allData'].chapters);
        };

        var successSend = function () {
            $ionicLoading.hide();
            $scope.problem = null;
            alert("تم إرسال الإستفتاء وسيتم الرد عليك في أقرب وقت");
        };

        $scope.sendFatwa = function (problem) {
            //console.log(problem);
            feqhiatService.sendFatwa($scope, successSend, problem)
        };

        //console.log($localStorage['allData']);
    }

)

  .controller('RecentCtrl', function($scope) {})

  .controller('SearchCtrl', function($scope, Chats) {
  // With the new view caching in Ionic, Controllers are only called
  // when they are recreated or on app start, instead of every page change.
  // To listen for when this page is active (for example, to refresh data),
  // listen for the $ionicView.enter event:
  //
  //$scope.$on('$ionicView.enter', function(e) {
  //});

  $scope.chats = Chats.all();
  $scope.remove = function(chat) {
    Chats.remove(chat);
  };
})

  .controller('AboutCtrl', function($scope) {
    $scope.settings = {
      enableFriends: true
    };
  })

  .controller('ChatDetailCtrl', function($scope, $stateParams, Chats) {
  $scope.chat = Chats.get($stateParams.chatId);
});

==> feqhiat_01_17_2017.zip: feqhiat/www/js/controllers.js <==
angular.module('starter.controllers', [])

    .controller('MainCtrl', function (constants, $scope, $ionicLoading, $rootScope,
                                      feqhiatService, $state, utilService, $localStorage) {

        //var counter = 0;
        $scope.$on('$ionicView.enter', function(){
            // Anything you can think of
            //alert("I entered");
            // reset all rootScope variables
            $rootScope.problem = new Object();
            //$rootScope.problem.is_answer = false;
            $rootScope.problem_id = 0;
        });


        $ionicLoading.show({
            template: 'الرجاء الانتظار'
        });

        var successAllData = function () {
            // save the data to local storage and use it
            $localStorage['allData'] = $scope.allData;
            $scope.allItems =  $localStorage['allData'].items;//$scope.allData.items;
            $ionicLoading.hide();
        };

        var successAllParam = function () {
            $ionicLoading.hide();
            // if version is different force to update
            //alert($localStorage['al_params']);
            if(constants.app_version != utilService.getParamByName("app_version", $scope.al_params).value)
            {
                /// show the update page
                console.log("update");
            }
            // if params not saved before
            else if($localStorage['al_params'] ==  undefined)
            {
                // save it to local storage
                console.log("update DB");
                //console.log(utilService.getParamByName("db_version", $localStorage['al_params']));
                $localStorage['al_params'] = $scope.al_params;
                feqhiatService.getAllData($scope, successAllData);
            }
            else if(utilService.getParamByName("db_version", $localStorage['al_params']).value != utilService.getParamByName("db_version", $scope.al_params).value)
            {
                console.log("update DB 2");
                console.log(utilService.getParamByName("db_version", $localStorage['al_params']));
                $localStorage['al_params'] = $scope.al_params;
                feqhiatService.getAllData($scope, successAllData);
            }
            // check if db version is the same in both server and local
            else //if($window.localStorage['al_params'].db_version == $scope.al_params.db_version)
            {
                $scope.allItems =  $localStorage['allData'].items;//$scope.allData.items;
                $ionicLoading.hide();
            }
            // if not the same, get all data
            //else
            //{
            //    feqhiatService.getAllData($scope, successAllData);
            //}

            // else use the local one
        };

        feqhiatService.getAllParam($scope, successAllParam);

        $scope.navigateToView = function (itemID)
        {
            $rootScope.problem = new Object();
            $rootScope.item_id = itemID;
            //alert($rootScope.item_id);
            if(itemID == 1) // Send Question
                $state.go('tab.send');
            else if(itemID == 5) // News
                $state.go('tab.books'); // TO DO
            else if(itemID == 6) // Control Panel
            {
                if(constants.is_admin)
                {
                    $rootScope.problem.is_answer = true;
                    $state.go('tab.problem_list');
                }

            }
            else if(itemID == 7) // my questions
            {
                $rootScope.problem.is_mine = true;
                $state.go('tab.problem_list');
            }
            else // show books
                $state.go('tab.books');
        };
    })

    .controller('BookCtrl',
        function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope) {
            //$rootScope.itemID = '';
            $scope.$on('$ionicView.enter', function(){
                $rootScope.book_id = '0';
                $rootScope.chapter_id = '0';
                $rootScope.problem_id = '0';
                $scope.allBooks =  $localStorage.allData.books;
            });


            $scope.navigateToView = function (bookID)
            {
                $rootScope.book_id = bookID;
                $state.go('tab.chapters');
            };
        }

    )

    .controller('ChapterCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope) {
        /*$rootScope.itemID = '';
        $rootScope.bookID = '';*/
        $scope.$on('$ionicView.enter', function() {
            $rootScope.chapter_id = '0';
            $rootScope.problem_id = '0';
            $scope.chapters = utilService.getBookChapters($rootScope.book_id, $localStorage.allData.chapters);
        });
        $scope.navigateToView = function (chapterID)
        {
            $rootScope.chapter_id = chapterID;
            $rootScope.problem = new Object();
            $rootScope.problem.item_id = $rootScope.item_id;
            $rootScope.problem.book_id = $rootScope.book_id;
            $rootScope.problem.chapter_id = $rootScope.chapter_id;
            $state.go('tab.problem_list');
        };
    }

)

    .controller('ProblemListCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {


        var successProblemList = function () {
            $scope.problem_list =  $scope.allData.data;//$scope.allData.items;
            $ionicLoading.hide();
        };
        $scope.$on('$ionicView.enter', function() {
            $rootScope.problem_id = 0;
            $scope.problem_list = null;
            feqhiatService.getProblemList($rootScope, $scope, successProblemList, $rootScope.problem);
        });

        $scope.navigateToView = function (problemID)
        {
            $rootScope.problem_id = problemID;
            if($rootScope.problem.is_answer)
                $state.go('tab.answer');
            else
                $state.go('tab.singleProblem');
        };
    }

)

    .controller('ProblemCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {
        var successProblemSolutions = function () {
            $scope.solutions =  $scope.allData.data;//$scope.allData.items;
            $ionicLoading.hide();
        };

        feqhiatService.getProblemSolutions($rootScope, $scope, successProblemSolutions);

    }

)

  .controller('SendCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {
        $scope.faqih_list = $localStorage['allData'].faqih;
        $scope.books = $localStorage['allData'].books;
        $scope.getChapters = function(bookID) {
            //console.log(bookID);
            $scope.chapters = utilService.getBookChapters(bookID, $localStorage['allData'].chapters);
        };

        var successSend = function () {
            $ionicLoading.hide();
            $scope.problem = null;
            alert("تم إرسال الإستفتاء وسيتم الرد عليك في أقرب وقت");
        };

        $scope.sendFatwa = function (problem) {
            //console.log(problem);
            feqhiatService.sendFatwa($scope, successSend, problem)
        };

        //console.log($localStorage['allData']);
    }

)

    .controller('AnswerCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {
        $scope.faqih_list = $localStorage['allData'].faqih;
        $scope.books = $localStorage['allData'].books;
        $scope.getChapters = function(bookID) {
            //console.log(bookID);
            $scope.chapters = utilService.getBookChapters(bookID, $localStorage['allData'].chapters);
        };

        var successSend = function () {
            $ionicLoading.hide();
            $scope.problem = null;
            alert("تم إرسال الإستفتاء وسيتم الرد عليك في أقرب وقت");
        };

        $scope.sendFatwa = function (problem) {
            //console.log(problem);
            feqhiatService.sendFatwa($scope, successSend, problem)
        };

        //console.log($localStorage['allData']);
    }

)

  .controller('RecentCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {

        //$scope.getProblemList = function (problem) {
            //console.log(problem);
            //feqhiatService.getProblemList($rootScope, $scope, successProblemList, problem);
        $rootScope.problem = new Object();
        $scope.$on('$ionicView.enter', function(){
        var prob = new Object();
        prob.latest = true;
        $rootScope.problem = prob;
        $state.go("tab.problem_list");
            });

        //console.log($localStorage['allData']);
    }

)

  .controller('SearchCtrl',
    function ($scope, feqhiatService, $state, utilService, $localStorage, $rootScope, $ionicLoading) {
        $scope.faqih_list = $localStorage['allData'].faqih;
        $scope.books = $localStorage['allData'].books;
        $scope.getChapters = function(bookID) {
            //console.log(bookID);
            $scope.chapters = utilService.getBookChapters(bookID, $localStorage['allData'].chapters);
        };

        $scope.getProblemList = function (problem) {
            //console.log(problem);
            //feqhiatService.getProblemList($rootScope, $scope, successProblemList, problem);
            $rootScope.problem = new Object();
            $rootScope.problem = problem;
            $state.go("tab.problem_list");
        };

        //console.log($localStorage['allData']);
    }

)
  // With the new view caching in Ionic, Controllers are only called
  // when they are recreated or on app start, instead of every page change.
  // To listen for when this page is active (for example, to refresh data),
  // listen for the $ionicView.enter event:
  //
  //$scope.$on('$ionicView.enter', function(e) {
  //});

//})

  .controller('AboutCtrl', function($scope) {
    $scope.settings = {
      enableFriends: true
    };
  })

  .controller('ChatDetailCtrl', function($scope, $stateParams, Chats) {
  $scope.chat = Chats.get($stateParams.chatId);
});
